# Test PostgreSQL TDE/EE

use strict;
use lib 't';
use TestLib;
use PgCommon;

use Test::More tests => 2 + 20 * @MAJORS;

$ENV{LC_MESSAGES} = 'C';
delete $ENV{LC_ALL};

open my $fh, ">", "/usr/local/bin/tde_encryption_key.sh";
print $fh "#!/bin/sh\n";
print $fh "echo d3b07384d113edec49eaa6238ad5ff00\n";
chmod 0755, $fh;
close $fh;
is_program_out 0, "/usr/local/bin/tde_encryption_key.sh", 0,
    "d3b07384d113edec49eaa6238ad5ff00\n";

foreach my $v (@MAJORS) {
    note "Running tests for $v";

    like_program_out 'root', "pg_createcluster $v ee --start", 0,
        qr/Data encryption is disabled/,
        "pg_createcluster $v ee without encryption";
    is_program_out 'postgres', "psql -XAtc 'show data_encryption'", 0, "off\n";
    program_ok 0, "pg_dropcluster $v ee --stop", 0;

    like_program_out 'root', "pg_createcluster $v ee --start -- -K /usr/local/bin/tde_encryption_key.sh", 0,
        qr/Data encryption is enabled/,
        "pg_createcluster $v ee with encryption";
    is_program_out 'postgres', "psql -XAtc 'show data_encryption'", 0, "on\n";
    like_program_out 'postgres', "/usr/lib/postgresql/$v/bin/pg_controldata /var/lib/postgresql/$v/ee", 0,
        qr/Data encryption: *on.*Data encryption fingerprint: *B157607C7168EFF6D2A31081B7FFB969/s;
    program_ok 0, "pg_dropcluster $v ee --stop", 0;

    check_clean;
}

unlink "/usr/local/bin/tde_encryption_key.sh";

# vim: filetype=perl
